@@ -44,7 +44,7 @@ struct app_data {
 	GList* allimgindir;
 	ArrowButton* prevarrowbut;
 	ArrowButton* nextarrowbut;
-	const gchar** rawext;
+	gchar** rawext;
 	zoom_t zoomlevel;
 	gboolean showimgparam;
 };
