@@ -3,6 +3,8 @@
  */
 #include <gtk/gtk.h>
 #include <hildon/hildon.h>
+#include <gdk/gdkx.h>
+#include <X11/Xatom.h>
 #include <string.h>
 #include "arrow-button.h"
 
@@ -278,6 +280,25 @@ arrow_button_on_clicked (GtkWidget *widget, GdkEventButton *event G_GNUC_UNUSED,
 }
 
 
+/**
+ * Force compositing to stay on
+ */
+static void
+arrow_button_force_compositing (GtkWidget *widget)
+{
+	int zero = 0;
+	Atom atom;
+    GdkDisplay *display = NULL;
+
+    display = gtk_widget_get_display(widget);
+    /* atom = XInternAtom(display,"_HILDON_NON_COMPOSITED_WINDOW",False); */
+    atom = gdk_x11_get_xatom_by_name_for_display(display,"_HILDON_NON_COMPOSITED_WINDOW");
+    XChangeProperty(GDK_DISPLAY_XDISPLAY (display),
+				    GDK_WINDOW_XID (GDK_WINDOW (widget->window)),atom,XA_INTEGER,32,
+					PropModeReplace,(unsigned char *)&zero,1);
+}
+
+
 /**
  * Creates a rounded rectangle.
  */
@@ -364,6 +385,8 @@ arrow_button_create_gfx (ArrowButton *self)
 
     gtk_widget_realize (overlay);
 
+    arrow_button_force_compositing (overlay);
+
     return overlay;
 }
 
