@@ -221,18 +221,15 @@ gboolean detect_hardware_key_press (GtkWidget *widget,GdkEventKey *event,app_dat
 
 	switch (event->keyval) {
 		case HILDON_HARDKEY_FULLSCREEN:
+		case GDK_space:
 			toggle_fullscreen_mode(widget,myapp);
 			return TRUE;
-		case GDK_space:
-			if (event->state & GDK_CONTROL_MASK) {
-				toggle_fullscreen_mode(widget,myapp);
-				return TRUE;
-			}
-			break;
 		case HILDON_HARDKEY_RIGHT:
+		case HILDON_HARDKEY_UP:
 			load_next_image(widget,myapp);
 			return TRUE;
 		case HILDON_HARDKEY_LEFT:
+		case HILDON_HARDKEY_DOWN:
 			load_prev_image(widget,myapp);
 			return TRUE;
 		case HILDON_HARDKEY_INCREASE:
